@@ -28,7 +28,7 @@
 #include <goffice/graph/gog-chart-map-3d.h>
 #include <goffice/graph/gog-data-allocator.h>
 #include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-persist.h>
@@ -226,7 +226,7 @@ gog_axis_base_parent_changed (GogObject *child, gboolean was_set)
 	GogAxisBase *axis_base = GOG_AXIS_BASE (child);
 
 	if (was_set) {
-		if (IS_GOG_AXIS (child))
+		if (GOG_IS_AXIS (child))
 			axis_base->axis = GOG_AXIS (child);
 		else
 			axis_base->axis = GOG_AXIS (child->parent);
@@ -322,7 +322,7 @@ gog_axis_base_set_position (GogAxisBase *axis_base, GogAxisPosition position)
 	g_return_if_fail (GOG_AXIS_BASE (axis_base) != NULL);
 
 	if (position == GOG_AXIS_AUTO) {
-		if (IS_GOG_AXIS (axis_base))
+		if (GOG_IS_AXIS (axis_base))
 			axis = GOG_AXIS (axis_base);
 		else
 			axis = GOG_AXIS (gog_object_get_parent (GOG_OBJECT (axis_base)));
@@ -337,7 +337,7 @@ gog_axis_base_set_position (GogAxisBase *axis_base, GogAxisPosition position)
 			lines = gog_object_get_children (GOG_OBJECT (aptr->data), NULL);
 			lines = g_slist_prepend (lines, aptr->data);
 			for (lptr = lines; lptr != NULL; lptr = lptr->next) {
-				if (lptr->data == axis_base || !IS_GOG_AXIS_BASE (lptr->data))
+				if (lptr->data == axis_base || !GOG_IS_AXIS_BASE (lptr->data))
 					continue;
 				position = gog_axis_base_get_position (GOG_AXIS_BASE (lptr->data));
 				if (position == GOG_AXIS_AT_HIGH )
@@ -365,7 +365,7 @@ gog_axis_base_get_clamped_position (GogAxisBase *axis_base)
 {
 	GogAxisPosition axis_pos;
 
-	g_return_val_if_fail (IS_GOG_AXIS_BASE (axis_base), GOG_AXIS_AT_LOW);
+	g_return_val_if_fail (GOG_IS_AXIS_BASE (axis_base), GOG_AXIS_AT_LOW);
 
 	axis_pos = axis_base->position;
 	if (axis_pos == GOG_AXIS_CROSS) {
@@ -456,7 +456,7 @@ cb_position_toggled (GtkWidget *button, AxisBasePrefs *state)
 			lines = gog_object_get_children (GOG_OBJECT (aptr->data), NULL);
 			lines = g_slist_prepend (lines, aptr->data);
 			for (lptr = lines; lptr != NULL; lptr = lptr->next) {
-				if (lptr->data == axis_base || !IS_GOG_AXIS_BASE (lptr->data))
+				if (lptr->data == axis_base || !GOG_IS_AXIS_BASE (lptr->data))
 					continue;
 				if (position == gog_axis_base_get_position (GOG_AXIS_BASE (lptr->data))) {
 					gog_axis_base_set_position (GOG_AXIS_BASE (lptr->data),
@@ -490,30 +490,21 @@ cb_padding_changed (GtkSpinButton *spin, GObject *axis_base)
 
 static void
 gog_axis_base_populate_editor (GogObject *gobj,
-			       GogEditor *editor,
+			       GOEditor *editor,
 			       GogDataAllocator *dalloc,
 			       GOCmdContext *cc)
 {
-	static char const *toggle_props[] = {
+	static char const * const toggle_props[] = {
 		"major-tick-labeled",
 		"major-tick-out",
 		"major-tick-in",
 		"minor-tick-out",
 		"minor-tick-in"
 	};
-	GogAxis *crossed_axis;
 	GogAxisBase *axis_base;
 	GladeXML *gui;
-	GtkListStore *store;
-	GtkTreeIter iter;
-	GtkWidget *combo, *data_editor, *container, *w;
-	GtkCellRenderer *cell;
-	GSList *axes, *ptr;
-	AxisBasePrefs *state;
 	GogAxisType crossed_axis_type, axis_type;
 	static guint axis_base_pref_page = 0;
-	unsigned axis_count;
-	unsigned crossed_axis_id;
 	unsigned i;
 	gboolean hide_position_box = TRUE;
 
@@ -522,7 +513,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 	if (!gog_object_is_visible (axis_base->axis))
 		return;
 
-	gog_editor_set_store_page (editor, &axis_base_pref_page);
+	go_editor_set_store_page (editor, &axis_base_pref_page);
 
 	axis_type = gog_axis_get_atype (axis_base->axis);
 	if (axis_type == GOG_AXIS_PSEUDO_3D) {
@@ -530,7 +521,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		return;
 	}
 
-	gui = go_libglade_new ("gog-axis-prefs.glade", "axis_base_pref_box", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new ("gog-axis-prefs.glade", "axis_base_pref_box", GETTEXT_PACKAGE, cc);
 	if (gui == NULL) {
 		(GOG_OBJECT_CLASS(gab_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 		return;
@@ -539,6 +530,14 @@ gog_axis_base_populate_editor (GogObject *gobj,
 	crossed_axis_type = gog_axis_base_get_crossed_axis_type (axis_base);
 	if (crossed_axis_type != GOG_AXIS_UNKNOWN &&
 	    axis_type != GOG_AXIS_CIRCULAR) {
+		GtkListStore *store;
+		GogDataEditor *deditor;
+		GtkWidget *combo, *container, *w;
+		GSList *axes, *ptr;
+		unsigned axis_count;
+		GtkCellRenderer *cell;
+		AxisBasePrefs *state;
+
 		store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_UINT);
 		combo = glade_xml_get_widget (gui, "cross_axis_combo");
 		gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
@@ -552,6 +551,10 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		axes = gog_chart_get_axes (axis_base->chart, crossed_axis_type);
 		axis_count = 0;
 		for (ptr = axes; ptr != NULL; ptr = ptr->next) {
+			GtkTreeIter iter;
+			GogAxis *crossed_axis;
+			unsigned crossed_axis_id;
+
 			crossed_axis = GOG_AXIS (ptr->data);
 			crossed_axis_id = gog_object_get_id (GOG_OBJECT (crossed_axis));
 			gtk_list_store_prepend (store, &iter);
@@ -567,10 +570,12 @@ gog_axis_base_populate_editor (GogObject *gobj,
 			gtk_widget_set_sensitive (GTK_WIDGET (combo), FALSE);
 		g_slist_free (axes);
 
-		data_editor = gog_data_allocator_editor (dalloc, GOG_DATASET (axis_base),
-							 GOG_AXIS_ELEM_CROSS_POINT, GOG_DATA_SCALAR);
+		deditor = gog_data_allocator_editor
+			(dalloc, GOG_DATASET (axis_base),
+			 GOG_AXIS_ELEM_CROSS_POINT, GOG_DATA_SCALAR);
 		container = glade_xml_get_widget (gui, "cross_location_alignment");
-		gtk_container_add (GTK_CONTAINER (container), data_editor);
+		gtk_container_add (GTK_CONTAINER (container),
+				   GTK_WIDGET (deditor));
 		gtk_widget_show_all (container);
 
 		state = g_new (AxisBasePrefs, 1);
@@ -578,7 +583,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		state->gui = gui;
 		g_signal_connect (G_OBJECT (combo), "changed",
 				  G_CALLBACK (cb_cross_axis_changed), state);
-		g_signal_connect (G_OBJECT (data_editor), "changed",
+		g_signal_connect (G_OBJECT (deditor), "changed",
 				  G_CALLBACK (cb_cross_location_changed), state);
 		g_object_set_data_full (G_OBJECT (combo),
 					"state", state, (GDestroyNotify) axis_base_pref_free);
@@ -601,7 +606,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 
 		hide_position_box = FALSE;
 	} else {
-		w = glade_xml_get_widget (gui, "cross_box");
+		GtkWidget *w = glade_xml_get_widget (gui, "cross_box");
 		gtk_widget_hide (w);
 	}
 
@@ -609,26 +614,25 @@ gog_axis_base_populate_editor (GogObject *gobj,
 	    axis_type == GOG_AXIS_Y ||
 	    axis_type == GOG_AXIS_Z ||
 	    axis_type == GOG_AXIS_RADIAL) {
-		w = glade_xml_get_widget (gui, "padding_spinbutton");
+		GtkWidget *w = glade_xml_get_widget (gui, "padding_spinbutton");
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), axis_base->padding);
 		g_signal_connect (G_CALLBACK (w), "value-changed",
 				  G_CALLBACK (cb_padding_changed), axis_base);
 		gtk_widget_set_sensitive (w, axis_base->position != GOG_AXIS_CROSS);
 		hide_position_box = FALSE;
 	} else {
-		w = glade_xml_get_widget (gui, "padding_box");
+		GtkWidget *w = glade_xml_get_widget (gui, "padding_box");
 		gtk_widget_hide (w);
 	}
 
 	if (hide_position_box) {
-		w = glade_xml_get_widget (gui, "position_box");
+		GtkWidget *w = glade_xml_get_widget (gui, "position_box");
 		gtk_widget_hide (w);
 	}
 
 	for (i = 0; i < G_N_ELEMENTS (toggle_props) ; i++) {
 		gboolean cur_val;
-
-		w = glade_xml_get_widget (gui, toggle_props[i]);
+		GtkWidget *w = glade_xml_get_widget (gui, toggle_props[i]);
 		g_object_get (G_OBJECT (gobj), toggle_props[i], &cur_val, NULL);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), cur_val);
 		g_signal_connect_object (G_OBJECT (w),
@@ -642,7 +646,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		gtk_widget_hide (w);
 	}
 
-	gog_editor_add_page (editor,
+	go_editor_add_page (editor,
 			     glade_xml_get_widget (gui, "axis_base_pref_box"),
 			     _("Layout"));
 
@@ -651,9 +655,9 @@ gog_axis_base_populate_editor (GogObject *gobj,
 #endif
 
 static void
-gog_axis_base_init_style (GogStyledObject *gso, GogStyle *style)
+gog_axis_base_init_style (GogStyledObject *gso, GOStyle *style)
 {
-	style->interesting_fields = GOG_STYLE_LINE | GOG_STYLE_FONT;
+	style->interesting_fields = GO_STYLE_LINE | GO_STYLE_FONT;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
 		style, GOG_OBJECT (gso), 0, FALSE);
 }
@@ -771,8 +775,8 @@ gog_axis_base_get_cross_location (GogAxisBase *axis_base)
 	g_return_val_if_fail (GOG_AXIS_BASE (axis_base) != NULL, 0.);
 
 	data = axis_base->cross_location.data;
-	if (data != NULL && IS_GO_DATA_SCALAR (data))
-		return go_data_scalar_get_value (GO_DATA_SCALAR (data));
+	if (GO_IS_DATA (data))
+		return go_data_get_scalar_value (data);
 
 	return 0.;
 }
@@ -794,7 +798,7 @@ gog_axis_base_get_padding (GogAxisBase *axis_base)
 
 GSF_CLASS_ABSTRACT (GogAxisBase, gog_axis_base,
 		    gog_axis_base_class_init, gog_axis_base_init,
-		    GOG_STYLED_OBJECT_TYPE);
+		    GOG_TYPE_STYLED_OBJECT);
 
 /************************************************************************/
 static gboolean gog_axis_base_view_point (GogView *view, double x, double y);
@@ -993,7 +997,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	GogAxisMap *map = NULL;
 	GogAxisTick *ticks;
 	GOGeometryAABR total_bbox, bbox;
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 	GOGeometryAABR txt_aabr;
 	GOGeometryOBR txt_obr;
 	GOGeometryOBR *obrs = NULL;
@@ -1012,7 +1016,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	cos_alpha = side == GO_SIDE_LEFT ? - sin (axis_angle) : + sin (axis_angle);
 	sin_alpha = side == GO_SIDE_LEFT ? + cos (axis_angle) : - cos (axis_angle);
 
-	is_line_visible = gog_style_is_line_visible (style);
+	is_line_visible = go_style_is_line_visible (style);
 	line_width = gog_renderer_line_size (renderer, style->line.width) / 2;
 
 	minor_tick_len = gog_renderer_pt2r (renderer, axis_base->minor.size_pts);
@@ -1106,7 +1110,7 @@ axis_line_render (GogAxisBase *axis_base,
 {
 	GogAxisMap *map = NULL;
 	GogAxisTick *ticks;
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 	GOGeometryOBR zero_obr;
 	GOGeometryOBR *obrs = NULL;
 	GOGeometrySide label_anchor = GO_SIDE_AUTO;
@@ -1136,7 +1140,7 @@ axis_line_render (GogAxisBase *axis_base,
 	axis_base_view->x_stop = x + w;
 	axis_base_view->y_stop = y + h;
 
-	is_line_visible = gog_style_is_line_visible (style);
+	is_line_visible = go_style_is_line_visible (style);
 	line_width = gog_renderer_line_size (renderer, style->line.width) / 2;
 
 	if (is_line_visible)
@@ -1325,7 +1329,7 @@ axis_circle_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr);
 	label_padding = txt_obr.w;
 
-	draw_ticks = gog_style_is_line_visible (axis_base->base.style) &&
+	draw_ticks = go_style_is_line_visible (axis_base->base.style) &&
 		(axis_base->major.tick_out || axis_base->minor.tick_out);
 
 	map = gog_chart_map_get_axis_map (c_map, 1);
@@ -1397,7 +1401,7 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 		go_path_arc (path, parms->cx, parms->cy, parms->rx, parms->ry,
 			     -parms->th1, -parms->th0);
 
-	is_line_visible = gog_style_is_line_visible (axis_base->base.style);
+	is_line_visible = go_style_is_line_visible (axis_base->base.style);
 	draw_major = axis_base->major.tick_in || axis_base->major.tick_out;
 	draw_minor = axis_base->minor.tick_in || axis_base->minor.tick_out;
 
@@ -2052,7 +2056,7 @@ gog_axis_base_view_point (GogView *view, double x, double y)
 		return FALSE;
 
 	/* FIXME: not nice */
-	if (IS_GOG_AXIS (view->model))
+	if (GOG_IS_AXIS (view->model))
 		plot_area = gog_chart_view_get_plot_area (view->parent);
 	else
 		plot_area = gog_chart_view_get_plot_area (view->parent->parent);
@@ -2092,7 +2096,7 @@ gog_axis_base_view_padding_request (GogView *view, GogViewAllocation const *bbox
 {
 	GogAxisSet axis_set;
 	GogAxisBase *axis_base = GOG_AXIS_BASE (view->model);
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 
 	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
 		return;
@@ -2130,7 +2134,7 @@ gog_axis_base_view_render (GogView *view, GogViewAllocation const *bbox)
 {
 	GogAxisSet axis_set;
 	GogAxisBase *axis_base = GOG_AXIS_BASE (view->model);
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 	GogViewAllocation const *plot_area;
 
 	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
@@ -2140,7 +2144,7 @@ gog_axis_base_view_render (GogView *view, GogViewAllocation const *bbox)
 		return;
 
 	/* FIXME: not nice */
-	if (IS_GOG_AXIS (view->model))
+	if (GOG_IS_AXIS (view->model))
 		plot_area = gog_chart_view_get_plot_area (view->parent);
 	else
 		plot_area = gog_chart_view_get_plot_area (view->parent->parent);
@@ -2186,7 +2190,7 @@ gog_axis_base_view_label_position_request (GogView *view,
 {
 	GogAxisSet axis_set;
 	GogAxisBase *axis_base = GOG_AXIS_BASE (view->model);
-	GogStyle *style = axis_base->base.style;
+	GOStyle *style = axis_base->base.style;
 	GogViewPadding padding = {0};
 
 	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
@@ -2230,7 +2234,7 @@ gog_axis_base_view_class_init (GogAxisBaseViewClass *gview_klass)
 
 GSF_CLASS (GogAxisBaseView, gog_axis_base_view,
 	   gog_axis_base_view_class_init, NULL,
-	   GOG_VIEW_TYPE)
+	   GOG_TYPE_VIEW)
 
 /*****************************************************************************/
 /*****************************************************************************/
@@ -2283,5 +2287,5 @@ gog_axis_line_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogAxisLine, gog_axis_line,
 		NULL, NULL, gog_axis_line_class_init, NULL,
-		NULL /*init*/, GOG_AXIS_BASE_TYPE, 0,
-		GSF_INTERFACE (gog_axis_line_dataset_init, GOG_DATASET_TYPE))
+		NULL /*init*/, GOG_TYPE_AXIS_BASE, 0,
+		GSF_INTERFACE (gog_axis_line_dataset_init, GOG_TYPE_DATASET))
