@@ -15,17 +15,27 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
 #ifndef GOG_AXIS_BASE_H
 #define GOG_AXIS_BASE_H
 
+#include <goffice/graph/goffice-graph.h>
 #include <glib-object.h>
 
 G_BEGIN_DECLS
 
+#define GOG_TYPE_AXIS_BASE	(gog_axis_base_get_type ())
+#define GOG_AXIS_BASE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_AXIS_BASE, GogAxisBase))
+#define GOG_IS_AXIS_BASE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_AXIS_BASE))
+
+GType gog_axis_base_get_type (void);
+
+GogAxis *gog_axis_base_get_crossed_axis (GogAxisBase *axis_base);
+double gog_axis_base_get_cross_location (GogAxisBase *axis_base);
+
 typedef enum {
 	GOG_AXIS_AT_LOW,
 	GOG_AXIS_CROSS,
@@ -33,15 +43,17 @@ typedef enum {
 	GOG_AXIS_AUTO
 } GogAxisPosition;
 
+GogAxisPosition gog_axis_base_get_clamped_position (GogAxisBase *axis_base);
+
 typedef enum {
 	GOG_AXIS_TICK_NONE,
 	GOG_AXIS_TICK_MAJOR,
 	GOG_AXIS_TICK_MINOR
 } GogAxisTickTypes;
 
-#define GOG_AXIS_LINE_TYPE	(gog_axis_line_get_type ())
-#define GOG_AXIS_LINE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_AXIS_LINE_TYPE, GogAxisLine))
-#define IS_GOG_AXIS_LINE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_AXIS_LINE_TYPE))
+#define GOG_TYPE_AXIS_LINE	(gog_axis_line_get_type ())
+#define GOG_AXIS_LINE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_AXIS_LINE, GogAxisLine))
+#define GOG_IS_AXIS_LINE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_AXIS_LINE))
 
 GType gog_axis_line_get_type (void);
 
