@@ -23,7 +23,7 @@
 #include <goffice/graph/gog-reg-curve.h>
 #include <goffice/graph/gog-data-allocator.h>
 #include <goffice/graph/gog-plot-engine.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-series-impl.h>
@@ -42,7 +42,7 @@
 #include <goffice/gtk/goffice-gtk.h>
 #endif
 
-#define GOG_REG_CURVE_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_REG_CURVE_TYPE, GogRegCurveClass))
+#define GOG_REG_CURVE_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_REG_CURVE, GogRegCurveClass))
 
 static GObjectClass *reg_curve_parent_klass;
 
@@ -54,9 +54,9 @@ enum {
 };
 
 static void
-gog_reg_curve_init_style (GogStyledObject *gso, GogStyle *style)
+gog_reg_curve_init_style (GogStyledObject *gso, GOStyle *style)
 {
-	style->interesting_fields = GOG_STYLE_LINE;
+	style->interesting_fields = GO_STYLE_LINE;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
 		style, GOG_OBJECT (gso), 0, FALSE);
 }
@@ -70,7 +70,7 @@ skip_invalid_toggled_cb (GtkToggleButton* btn, GObject *obj)
 
 static void
 gog_reg_curve_populate_editor (GogObject	*gobj, 
-			       GogEditor	*editor, 
+			       GOEditor	*editor, 
 			       GogDataAllocator	*dalloc, 
 			       GOCmdContext	*cc)
 {
@@ -79,11 +79,11 @@ gog_reg_curve_populate_editor (GogObject	*gobj,
 	GladeXML *gui;
 	GogDataset *set = GOG_DATASET (gobj);
 
-	gui = go_libglade_new ("gog-reg-curve-prefs.glade", "reg-curve-prefs", GETTEXT_PACKAGE, cc);
+	gui = go_glade_new ("gog-reg-curve-prefs.glade", "reg-curve-prefs", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
-	gog_editor_add_page (editor, 
+	go_editor_add_page (editor, 
 			     glade_xml_get_widget (gui, "reg-curve-prefs"),
 			     _("Details"));
 
@@ -237,8 +237,8 @@ gog_reg_curve_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogRegCurve, gog_reg_curve,
 	   NULL, NULL, gog_reg_curve_class_init, NULL,
-	   gog_reg_curve_init, GOG_TREND_LINE_TYPE, G_TYPE_FLAG_ABSTRACT,
-		GSF_INTERFACE (gog_reg_curve_dataset_init, GOG_DATASET_TYPE))
+	   gog_reg_curve_init, GOG_TYPE_TREND_LINE, G_TYPE_FLAG_ABSTRACT,
+		GSF_INTERFACE (gog_reg_curve_dataset_init, GOG_TYPE_DATASET))
 
 static double
 gog_reg_curve_get_value_at (GogRegCurve *reg_curve, double x)
@@ -262,15 +262,13 @@ void
 gog_reg_curve_get_bounds (GogRegCurve *reg_curve, double *xmin, double *xmax)
 {
 	if (reg_curve->bounds[0].data) {
-		*xmin = go_data_scalar_get_value (
-			GO_DATA_SCALAR (reg_curve->bounds[0].data));
+		*xmin = go_data_get_scalar_value (reg_curve->bounds[0].data);
 		if (*xmin == go_nan || !go_finite (*xmin))
 			*xmin = -DBL_MAX;
 	} else
 		*xmin = -DBL_MAX;
 	if (reg_curve->bounds[1].data) {
-		*xmax = go_data_scalar_get_value (
-			GO_DATA_SCALAR (reg_curve->bounds[1].data));
+		*xmax = go_data_get_scalar_value (reg_curve->bounds[1].data);
 		if (*xmax == go_nan || !go_finite (*xmax))
 			*xmax = DBL_MAX;
 	} else
@@ -282,9 +280,9 @@ gog_reg_curve_get_bounds (GogRegCurve *reg_curve, double *xmin, double *xmax)
 typedef GogView		GogRegCurveView;
 typedef GogViewClass	GogRegCurveViewClass;
 
-#define GOG_REG_CURVE_VIEW_TYPE	(gog_reg_curve_view_get_type ())
-#define GOG_REG_CURVE_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_REG_CURVE_VIEW_TYPE, GogRegCurveView))
-#define IS_GOG_REG_CURVE_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_REG_CURVE_VIEW_TYPE))
+#define GOG_TYPE_REG_CURVE_VIEW	(gog_reg_curve_view_get_type ())
+#define GOG_REG_CURVE_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_REG_CURVE_VIEW, GogRegCurveView))
+#define GOG_IS_REG_CURVE_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_REG_CURVE_VIEW))
 
 static GogViewClass *reg_curve_view_parent_klass;
 
@@ -297,7 +295,7 @@ gog_reg_curve_view_render (GogView *view, GogViewAllocation const *bbox)
 	GogChart *chart = GOG_CHART (GOG_OBJECT (plot)->parent);
 	GogAxisMap *x_map, *y_map;
 	GogChartMap *chart_map;
-	GogStyle *style;
+	GOStyle *style;
 	GOPath *path;
 	GSList *ptr;
 	double *x, *y;
@@ -367,4 +365,4 @@ gog_reg_curve_view_class_init (GogRegCurveViewClass *gview_klass)
 
 static GSF_CLASS (GogRegCurveView, gog_reg_curve_view,
 		  gog_reg_curve_view_class_init, NULL,
-		  GOG_VIEW_TYPE)
+		  GOG_TYPE_VIEW)
