@@ -386,9 +386,10 @@ gog_series_get_property (GObject *obj, guint param_id,
 
 #ifdef GOFFICE_WITH_GTK
 static unsigned
-make_dim_editor (GtkTable *table, unsigned row, GtkWidget *editor,
+make_dim_editor (GtkTable *table, unsigned row, GogDataEditor *deditor,
 		 char const *name, GogSeriesPriority priority, gboolean is_shared)
 {
+	GtkWidget *editor = GTK_WIDGET (deditor);
 	char *txt = g_strdup_printf (
 		((priority != GOG_SERIES_REQUIRED) ? "(_%s):" : "_%s:"), _(name));
 	GtkWidget *label = gtk_label_new_with_mnemonic (txt);
@@ -683,7 +684,7 @@ gog_series_class_init (GogSeriesClass *klass)
 			_("Interpolation"),
 			_("Type of line interpolation"),
 			"linear",
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_INTERPOLATION_SKIP_INVALID,
 		g_param_spec_boolean ("interpolation-skip-invalid", 
 			_("Interpolation skip invalid"),
