@@ -22,20 +22,22 @@
 #define GOG_THEME_H
 
 #include <goffice/graph/goffice-graph.h>
+#include <goffice/graph/goffice-graph.h>
+#include <goffice/utils/go-style.h>
 #include <glib-object.h>
 
 G_BEGIN_DECLS
 
-#define GOG_THEME_TYPE	(gog_theme_get_type ())
-#define GOG_THEME(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_THEME_TYPE, GogTheme))
-#define IS_GOG_THEME(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_THEME_TYPE))
+#define GOG_TYPE_THEME	(gog_theme_get_type ())
+#define GOG_THEME(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_THEME, GogTheme))
+#define GOG_IS_THEME(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_THEME))
 
 GType gog_theme_get_type (void);
 
 GogTheme   *gog_theme_new        	(char const *name);
 GogTheme   *gog_theme_new_from_file     (char const *name, char const *file);
 char const *gog_theme_get_name 		(GogTheme const *theme);
-void 	    gog_theme_fillin_style    	(GogTheme const *theme, GogStyle *style,
+void 	    gog_theme_fillin_style    	(GogTheme const *theme, GOStyle *style,
 				         GogObject const *obj, int ind,
 				         gboolean complete_overwrite);
 
