@@ -1,5 +1,5 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * go-rotation-sel.c: A widget to select a text orientation
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- **/
+ */
 #include <goffice/goffice-config.h>
 #include "go-rotation-sel.h"
 
@@ -213,7 +213,7 @@ grs_init (GORotationSel *grs)
 {
 	GtkWidget *w;
 
-	grs->gui = go_libglade_new ("go-rotation-sel.glade", "toplevel", GETTEXT_PACKAGE, NULL);
+	grs->gui = go_glade_new ("go-rotation-sel.glade", "toplevel", GETTEXT_PACKAGE, NULL);
 	if (grs->gui == NULL)
 		return;
 
@@ -279,20 +279,20 @@ GSF_CLASS (GORotationSel, go_rotation_sel,
 GtkWidget *
 go_rotation_sel_new (void)
 {
-	return g_object_new (GO_ROTATION_SEL_TYPE, NULL);
+	return g_object_new (GO_TYPE_ROTATION_SEL, NULL);
 }
 
 int
 go_rotation_sel_get_rotation (GORotationSel const *grs)
 {
-	g_return_val_if_fail (IS_GO_ROTATION_SEL (grs), 0);
+	g_return_val_if_fail (GO_IS_ROTATION_SEL (grs), 0);
 	return grs->angle;
 }
 
 void
 go_rotation_sel_set_rotation (GORotationSel *grs, int angle)
 {
-	g_return_if_fail (IS_GO_ROTATION_SEL (grs));
+	g_return_if_fail (GO_IS_ROTATION_SEL (grs));
 	if (grs->angle != angle) {
 		grs->angle = angle;
 		gtk_spin_button_set_value (grs->rotate_spinner, grs->angle);
