@@ -31,11 +31,12 @@
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-format.h>
+#include <goffice/utils/go-persist.h>
 #include <goffice/app/module-plugin-defs.h>
 
 #include <glib/gi18n-lib.h>
@@ -156,14 +157,12 @@ gog_plot1_5d_update (GogObject *obj)
 	GogPlot1_5dClass *klass = GOG_PLOT1_5D_GET_CLASS (obj);
 	GogSeries1_5d const *series;
 	unsigned i, num_elements, num_series;
-	double **vals, minima, maxima;
+	double minima, maxima;
 	double old_minima, old_maxima;
-	unsigned *lengths;
 	GSList *ptr;
 	GOData *index_dim = NULL;
 	GogPlot *plot_that_labeled_axis;
 	GogAxis *axis;
-	GogErrorBar **errors;
 	gboolean index_changed = FALSE;
 
 	old_minima =  model->minima;
@@ -190,12 +189,10 @@ gog_plot1_5d_update (GogObject *obj)
 			if (gog_error_bar_is_visible (series->errors))
 				gog_error_bar_get_minmax (series->errors, &minima, &maxima);
 			else
-				go_data_vector_get_minmax (GO_DATA_VECTOR (
-					series->base.values[1].data), &minima, &maxima);
+				go_data_get_bounds (series->base.values[1].data, &minima, &maxima);
 			if (series->base.plot->desc.series.num_dim == 3) {
 				double tmp_min, tmp_max;
-				go_data_vector_get_minmax (GO_DATA_VECTOR (
-					series->base.values[2].data), &tmp_min, &tmp_max);
+				go_data_get_bounds (series->base.values[2].data, &tmp_min, &tmp_max);
 				if (minima > tmp_min )
 					minima = tmp_min;
 				if (maxima < tmp_max)
@@ -208,6 +205,7 @@ gog_plot1_5d_update (GogObject *obj)
 		}
 		if (model->fmt == NULL)
 			model->fmt = go_data_preferred_fmt (series->base.values[1].data);
+		model->date_conv = go_data_date_conv (series->base.values[1].data);
 		index_dim = GOG_SERIES (series)->values[0].data;
 	}
 	axis = gog_plot1_5d_get_index_axis (model);
@@ -228,26 +226,32 @@ gog_plot1_5d_update (GogObject *obj)
 	if (num_elements <= 0 || num_series <= 0)
 		model->minima = model->maxima = 0.;
 	else if (model->type != GOG_1_5D_NORMAL) {
-		vals = g_alloca (num_series * sizeof (double *));
-		errors = g_alloca (num_series * sizeof (GogErrorBar *));
-		lengths = g_alloca (num_series * sizeof (unsigned));
+		double **vals = g_new0 (double *, num_series);
+		GogErrorBar **errors = g_new0 (GogErrorBar *, num_series);
+		unsigned *lengths = g_new0 (unsigned, num_series);
+
 		i = 0;
-		for (ptr = model->base.series ; ptr != NULL ; ptr = ptr->next, i++) {
+		for (ptr = model->base.series ; ptr != NULL ; ptr = ptr->next) {
 			series = ptr->data;
 			/* we are guaranteed that at least 1 series is valid above */
-			if (!gog_series_is_valid (GOG_SERIES (series)))
+			if (!gog_series_is_valid (GOG_SERIES (series))) {
 				continue;
-			vals[i] = go_data_vector_get_values (
-				GO_DATA_VECTOR (series->base.values[1].data));
+			}
+			vals[i] = go_data_get_values (series->base.values[1].data);
 			g_object_get (G_OBJECT (series), "errors", errors + i, NULL);
 			if (errors[i])
 				g_object_unref (errors[i]);
-			lengths[i] = go_data_vector_get_len (
-				GO_DATA_VECTOR (series->base.values[1].data));
+			lengths[i] = go_data_get_vector_size (series->base.values[1].data);
+
+			i++;
 		}
 
 		if (klass->update_stacked_and_percentage)
 			klass->update_stacked_and_percentage (model, vals, errors, lengths);
+
+		g_free (vals);
+		g_free (errors);
+		g_free (lengths);
 	}
 
 	if (old_minima != model->minima || old_maxima != model->maxima)
@@ -278,6 +282,10 @@ gog_plot1_5d_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 			}
 		} else if (bounds->fmt == NULL && model->fmt != NULL)
 			bounds->fmt = go_format_ref (model->fmt);
+
+		if (model->date_conv)
+			bounds->date_conv = model->date_conv;
+
 		return NULL;
 	} else if (axis == gog_axis_get_atype (gog_plot1_5d_get_index_axis (model))) {
 		GSList *ptr;
@@ -303,6 +311,12 @@ gog_1_5d_supports_vary_style_by_element (GogPlot const *plot)
 	GogPlot1_5d *gog_1_5d = GOG_PLOT1_5D (plot);
 	return gog_1_5d->type == GOG_1_5D_NORMAL;
 }
+static gboolean
+gog_1_5d_enum_in_reverse (GogPlot const *plot)
+{
+	GogPlot1_5d *gog_1_5d = GOG_PLOT1_5D (plot);
+	return gog_1_5d->type != GOG_1_5D_NORMAL; /* stacked or percentage */
+}
 
 static void
 gog_plot1_5d_class_init (GogPlotClass *plot_klass)
@@ -320,13 +334,13 @@ gog_plot1_5d_class_init (GogPlotClass *plot_klass)
 			_("Type"),
 			_("How to group multiple series, normal, stacked, as_percentage"),
 			"normal", 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_1_5D_PROP_IN_3D,
 		g_param_spec_boolean ("in-3d", 
 			_("In 3d"),
 			_("Placeholder to allow us to round trip pseudo 3d state"),
 			FALSE, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	gog_klass->update	= gog_plot1_5d_update;
 
@@ -345,18 +359,19 @@ gog_plot1_5d_class_init (GogPlotClass *plot_klass)
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
 	}
-	plot_klass->desc.num_series_min = 1;
 	plot_klass->desc.num_series_max = G_MAXINT;
 	plot_klass->series_type = gog_series1_5d_get_type ();
 	plot_klass->axis_get_bounds   	= gog_plot1_5d_axis_get_bounds;
 	plot_klass->axis_set	      	= GOG_AXIS_SET_XY;
 	plot_klass->supports_vary_style_by_element = gog_1_5d_supports_vary_style_by_element;
+	plot_klass->enum_in_reverse	= gog_1_5d_enum_in_reverse;
 }
 
 static void
 gog_plot1_5d_init (GogPlot1_5d *plot)
 {
 	plot->fmt = NULL;
+	plot->date_conv = NULL;
 	plot->in_3d = FALSE;
 	plot->support_series_lines = FALSE;
 	plot->support_drop_lines = FALSE;
@@ -365,7 +380,7 @@ gog_plot1_5d_init (GogPlot1_5d *plot)
 
 GSF_DYNAMIC_CLASS_ABSTRACT (GogPlot1_5d, gog_plot1_5d,
 	gog_plot1_5d_class_init, gog_plot1_5d_init,
-	GOG_PLOT_TYPE)
+	GOG_TYPE_PLOT)
 
 /*****************************************************************************/
 
@@ -474,18 +489,16 @@ gog_series1_5d_update (GogObject *obj)
 	unsigned old_num = series->base.num_elements;
 
 	if (series->base.values[1].data != NULL) {
-		vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
-		len = go_data_vector_get_len 
-			(GO_DATA_VECTOR (series->base.values[1].data));
+		vals = go_data_get_values (series->base.values[1].data);
+		len = go_data_get_vector_size (series->base.values[1].data);
 	}
 	series->base.num_elements = len;
 
 	if (series->base.plot->desc.series.num_dim == 3) {
 		int tmp = 0;
 		if (series->base.values[2].data != NULL) {
-			vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[2].data));
-			tmp = go_data_vector_get_len 
-				(GO_DATA_VECTOR (series->base.values[2].data));
+			vals = go_data_get_values (series->base.values[2].data);
+			tmp = go_data_get_vector_size (series->base.values[2].data);
 		}
 		if (tmp < len)
 			len = tmp;
@@ -543,10 +556,10 @@ gog_series1_5d_get_property (GObject *obj, guint param_id,
 }
 
 #ifdef GOFFICE_WITH_GTK
-#include <gtk/gtklabel.h>
+#include <gtk/gtk.h>
 static void 
 gog_series1_5d_populate_editor (GogObject *obj,
-				GogEditor *editor,
+				GOEditor *editor,
 				GogDataAllocator *dalloc,
 				GOCmdContext *cc)
 {
@@ -564,7 +577,7 @@ gog_series1_5d_populate_editor (GogObject *obj,
 	else
 		g_object_get (G_OBJECT (series->plot), "horizontal", &horizontal, NULL);
 	error_page = gog_error_bar_prefs (series, "errors", horizontal, dalloc, cc);
-	gog_editor_add_page (editor, error_page, _("Error bars"));
+	go_editor_add_page (editor, error_page, _("Error bars"));
 }
 #endif
 
@@ -628,8 +641,8 @@ gog_series1_5d_class_init (GogObjectClass *obj_klass)
 		g_param_spec_object ("errors", 
 			_("Error bars"),
 			_("GogErrorBar *"),
-			GOG_ERROR_BAR_TYPE, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GOG_TYPE_ERROR_BAR, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 }
 
 static void
@@ -646,7 +659,7 @@ gog_series1_5d_init (GObject *obj)
 
 GSF_DYNAMIC_CLASS (GogSeries1_5d, gog_series1_5d,
 	gog_series1_5d_class_init, gog_series1_5d_init,
-	GOG_SERIES_TYPE)
+	GOG_TYPE_SERIES)
 
 /* Plugin initialization */
 
@@ -658,10 +671,13 @@ go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 	gog_series1_5d_register_type (module);
 	gog_barcol_plot_register_type (module);
 	gog_barcol_view_register_type (module);
+	gog_barcol_series_register_type (module);
+	gog_barcol_series_element_register_type (module);
 	gog_dropbar_plot_register_type (module);
 	gog_dropbar_view_register_type (module);
 	gog_line_series_register_type (module);
 	gog_line_series_view_register_type (module);
+	gog_line_series_element_register_type (module);
 	gog_line_plot_register_type (module);
 	gog_area_plot_register_type (module);
 	gog_line_view_register_type (module);
