@@ -26,12 +26,13 @@
 #include <goffice/graph/gog-chart-map.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-series-lines.h>
-#include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-view.h>
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
@@ -41,29 +42,29 @@
 typedef GogSeriesElement GogBarColSeriesElement;
 typedef GogSeriesElementClass GogBarColSeriesElementClass;
 
-#define GOG_BARCOL_SERIES_ELEMENT_TYPE	(gog_barcol_series_element_get_type ())
-#define GOG_BARCOL_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_BARCOL_SERIES_ELEMENT_TYPE, GogBarColSeriesElement))
-#define GOG_IS_BARCOL_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_BARCOL_SERIES_ELEMENT_TYPE))
+#define GOG_TYPE_BARCOL_SERIES_ELEMENT	(gog_barcol_series_element_get_type ())
+#define GOG_BARCOL_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_BARCOL_SERIES_ELEMENT, GogBarColSeriesElement))
+#define GOG_IS_BARCOL_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_BARCOL_SERIES_ELEMENT))
 GType gog_barcol_series_element_get_type (void);
 
 GSF_DYNAMIC_CLASS (GogBarColSeriesElement, gog_barcol_series_element,
 	NULL, NULL,
-	GOG_SERIES_ELEMENT_TYPE)
+	GOG_TYPE_SERIES_ELEMENT)
 
 /******************************************************************************/
 
 typedef GogSeries1_5d GogBarColSeries;
 typedef GogSeries1_5dClass GogBarColSeriesClass;
 
-#define GOG_BARCOL_SERIES_TYPE	(gog_barcol_series_eget_type ())
-#define GOG_BARCOL_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_BARCOL_SERIES_TYPE, GogBarColSeries))
-#define GOG_IS_BARCOL_SERIEST(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_BARCOL_SERIES_TYPE))
+#define GOG_TYPE_BARCOL_SERIES	(gog_barcol_series_eget_type ())
+#define GOG_BARCOL_SERIES(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_BARCOL_SERIES, GogBarColSeries))
+#define GOG_IS_BARCOL_SERIEST(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_BARCOL_SERIES))
 GType gog_barcol_series_get_type (void);
 
 static void
 gog_barcol_series_class_init (GogSeriesClass *series_klass)
 {
-	series_klass->series_element_type = GOG_BARCOL_SERIES_ELEMENT_TYPE;
+	series_klass->series_element_type = GOG_TYPE_BARCOL_SERIES_ELEMENT;
 }
 
 GSF_DYNAMIC_CLASS (GogBarColSeries, gog_barcol_series,
@@ -140,11 +141,11 @@ gog_barcol_plot_type_name (G_GNUC_UNUSED GogObject const *item)
 extern gpointer gog_barcol_plot_pref (GogBarColPlot *barcol, GOCmdContext *cc);
 static void
 gog_barcol_plot_populate_editor (GogObject *item,
-				 GogEditor *editor,
+				 GOEditor *editor,
 			G_GNUC_UNUSED GogDataAllocator *dalloc,
 			GOCmdContext *cc)
 {
-	gog_editor_add_page (editor,
+	go_editor_add_page (editor,
 			     gog_barcol_plot_pref (GOG_BARCOL_PLOT (item), cc),
 			     _("Properties"));
 	(GOG_OBJECT_CLASS(gog_barcol_parent_klass)->populate_editor) (item, editor, dalloc, cc);
@@ -259,7 +260,7 @@ gog_barcol_plot_class_init (GogPlot1_5dClass *gog_plot_1_5d_klass)
 	gog_object_klass->populate_editor	= gog_barcol_plot_populate_editor;
 	gog_object_klass->view_type	= gog_barcol_view_get_type ();
 
-	plot_klass->desc.series.style_fields	= GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+	plot_klass->desc.series.style_fields	= GO_STYLE_OUTLINE | GO_STYLE_FILL;
 	plot_klass->series_type = gog_barcol_series_get_type ();
 	plot_klass->axis_get_bounds   		= gog_barcol_axis_get_bounds;
 
@@ -368,7 +369,7 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 	unsigned num_elements = gog_1_5d_model->num_elements;
 	unsigned num_series = gog_1_5d_model->num_series;
 	GogPlot1_5dType const type = gog_1_5d_model->type;
-	GogStyle **styles;
+	GOStyle **styles;
 	ErrorBarData **error_data;
 	GogErrorBar **errors;
 	GogSeriesLines **lines;
@@ -400,28 +401,26 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 
 	vals = g_alloca (num_series * sizeof (double *));
 	lengths = g_alloca (num_series * sizeof (unsigned));
-	styles = g_alloca (num_series * sizeof (GogStyle *));
+	styles = g_alloca (num_series * sizeof (GOStyle *));
 	errors = g_alloca (num_series * sizeof (GogErrorBar *));
 	error_data = g_alloca (num_series * sizeof (ErrorBarData *));
 	lines = g_alloca (num_series * sizeof (GogSeriesLines *));
 	paths = g_alloca (num_series * sizeof (GOPath *));
 	overrides = g_alloca (num_series * sizeof (GSList *));
-	
+
 	i = 0;
 	for (ptr = gog_1_5d_model->base.series ; ptr != NULL ; ptr = ptr->next) {
 		series = ptr->data;
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			continue;
-		vals[i] = go_data_vector_get_values (
-			GO_DATA_VECTOR (series->base.values[1].data));
-		lengths[i] = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->base.values[1].data));
+		vals[i] = go_data_get_values (series->base.values[1].data);
+		lengths[i] = go_data_get_vector_size (series->base.values[1].data);
 		styles[i] = GOG_STYLED_OBJECT (series)->style;
 		errors[i] = series->errors;
 		overrides[i] = gog_series_get_overrides (GOG_SERIES (series));
-		if (gog_error_bar_is_visible (series->errors)) 
+		if (gog_error_bar_is_visible (series->errors))
 			error_data[i] = g_malloc (sizeof (ErrorBarData) * lengths[i]);
-		else 
+		else
 			error_data[i] = NULL;
 		if (series->has_series_lines && lengths[i] > 0) {
 			if (!role)
@@ -495,8 +494,8 @@ gog_barcol_view_render (GogView *view, GogViewAllocation const *bbox)
 					gse = GOG_SERIES_ELEMENT (overrides[j]->data);
 					overrides[j] = overrides[j]->next;
 					gog_renderer_push_style (view->renderer,
-						gog_styled_object_get_style (
-							GOG_STYLED_OBJECT (gse)));
+						go_styled_object_get_style (
+							GO_STYLED_OBJECT (gse)));
 			} else
 				gog_renderer_push_style (view->renderer, styles[j]);
 			barcol_draw_rect (rend, is_vertical, x_map, y_map, &work);
@@ -570,4 +569,4 @@ gog_barcol_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogBarColView, gog_barcol_view,
 	gog_barcol_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
