@@ -55,7 +55,7 @@ gog_contour_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality_cha
 	unsigned nticks;
 	double *x, val;
 	GogSeries *series = GOG_SERIES (plot->base.series->data);
-	GODataMatrix *mat = GO_DATA_MATRIX (series->values[2].data);
+	GOData *mat = series->values[2].data;
 	unsigned n = plot->rows * plot->columns;
 	double *data, minimum, maximum, slope, offset = 0.;
 	unsigned max;
@@ -93,7 +93,7 @@ gog_contour_plot_build_matrix (GogXYZPlot const *plot, gboolean *cardinality_cha
 	for (i = 0; i < plot->rows; i++)
 		for (j = 0; j < plot->columns; j++) {
 			val = gog_axis_map_to_view (map,
-					go_data_matrix_get_value (mat, i, j));
+					go_data_get_matrix_value (mat, i, j));
 			if (fabs (val) == DBL_MAX)
 				val = go_nan;
 			else {
@@ -134,7 +134,7 @@ gog_contour_plot_foreach_elem  (GogPlot *plot, gboolean only_visible,
 {
 	unsigned i, j, nticks;
 	char *label;
-	GogStyle *style = gog_style_new ();
+	GOStyle *style = go_style_new ();
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (plot));
 	GogAxis *axis = plot->axis[GOG_AXIS_PSEUDO_3D];
 	GOColor *color;
@@ -163,10 +163,10 @@ gog_contour_plot_foreach_elem  (GogPlot *plot, gboolean only_visible,
 	}
 	g_object_unref (style);
 
-	style = gog_style_new ();
-	style->interesting_fields = GOG_STYLE_FILL;
-	style->disable_theming = GOG_STYLE_ALL;
-	style->fill.type = GOG_FILL_STYLE_PATTERN;
+	style = go_style_new ();
+	style->interesting_fields = GO_STYLE_FILL;
+	style->disable_theming = GO_STYLE_ALL;
+	style->fill.type = GO_STYLE_FILL_PATTERN;
 	style->fill.pattern.pattern = GO_PATTERN_SOLID;
 
 	if (gog_axis_is_inverted (axis)) {
@@ -237,7 +237,7 @@ gog_contour_plot_init (GogContourPlot *contour)
 
 GSF_DYNAMIC_CLASS (GogContourPlot, gog_contour_plot,
 	gog_contour_plot_class_init, gog_contour_plot_init,
-	GOG_XYZ_PLOT_TYPE)
+	GOG_TYPE_XYZ_PLOT)
 
 /*****************************************************************************/
 
@@ -250,7 +250,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 {
 	GogXYZPlot const *plot = GOG_XYZ_PLOT (view->model);
 	GogSeries const *series;
-	GODataVector *x_vec = NULL, *y_vec = NULL;
+	GOData *x_vec = NULL, *y_vec = NULL;
 	GogAxisMap *x_map, *y_map;
 	double zval0, zval1, zval2 = 0., zval3, t;
 	double x[4], y[4], zval[4];
@@ -259,7 +259,7 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 	int k, kmax, r = 0, s, h;
 	unsigned i, imax, j, jmax;
 	GogRenderer *rend = view->renderer;
-	GogStyle *style;
+	GOStyle *style;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (plot));
 	double x0, x1, y0, y1;
 	GOPath *path, *lines;
@@ -311,8 +311,8 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 		x1 = gog_axis_map_to_view (x_map, 1.);
 	} else {
 		x_vec = gog_xyz_plot_get_x_vals (GOG_XYZ_PLOT (plot));
-		x0 = gog_axis_map_to_view (x_map, go_data_vector_get_value (x_vec, 0));
-		x1 = gog_axis_map_to_view (x_map, go_data_vector_get_value (x_vec, 1));
+		x0 = gog_axis_map_to_view (x_map, go_data_get_vector_value (x_vec, 0));
+		x1 = gog_axis_map_to_view (x_map, go_data_get_vector_value (x_vec, 1));
 	}
 	ydiscrete = gog_axis_is_discrete (plot->base.axis[1]) ||
 			series->values[(plot->transposed)? 0: 1].data == NULL;
@@ -321,12 +321,12 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 		y1 = gog_axis_map_to_view (y_map, 1.);
 	} else {
 		y_vec = gog_xyz_plot_get_y_vals (GOG_XYZ_PLOT (plot));
-		y0 = gog_axis_map_to_view (y_map, go_data_vector_get_value (y_vec, 0));
-		y1 = gog_axis_map_to_view (y_map, go_data_vector_get_value (y_vec, 1));
+		y0 = gog_axis_map_to_view (y_map, go_data_get_vector_value (y_vec, 0));
+		y1 = gog_axis_map_to_view (y_map, go_data_get_vector_value (y_vec, 1));
 	}
 	cw = (x1 > x0) == (y1 > y0);
 
-	style = gog_style_new ();
+	style = go_style_new ();
 	path = go_path_new ();
 	go_path_set_options (path, GO_PATH_OPTIONS_SHARP);
 	/* build the colors table */
@@ -343,30 +343,30 @@ gog_contour_view_render (GogView *view, GogViewAllocation const *bbox)
 	gog_renderer_push_clip_rectangle (rend, view->residual.x, view->residual.y,
 					  view->residual.w, view->residual.h);
 
-	style = gog_style_new ();
-	style->interesting_fields = GOG_STYLE_FILL | GOG_STYLE_OUTLINE;
-	style->disable_theming = GOG_STYLE_ALL;
-	style->fill.type = GOG_FILL_STYLE_PATTERN;
+	style = go_style_new ();
+	style->interesting_fields = GO_STYLE_FILL | GO_STYLE_OUTLINE;
+	style->disable_theming = GO_STYLE_ALL;
+	style->fill.type = GO_STYLE_FILL_PATTERN;
 	style->fill.pattern.pattern = GO_PATTERN_SOLID;
 
 	lines = go_path_new ();
-	
+
 	for (j = 1; j < jmax; j++) {
 		if (xdiscrete) {
 			x0 = gog_axis_map_to_view (x_map, j);
 			x1 = gog_axis_map_to_view (x_map, j + 1);
 		} else {
-			x0 = gog_axis_map_to_view (x_map, go_data_vector_get_value (x_vec, j - 1));
-			x1 = gog_axis_map_to_view (x_map, go_data_vector_get_value (x_vec, j));
+			x0 = gog_axis_map_to_view (x_map, go_data_get_vector_value (x_vec, j - 1));
+			x1 = gog_axis_map_to_view (x_map, go_data_get_vector_value (x_vec, j));
 		}
-		
+
 		for (i = 1; i < imax; i++) {
 			if (ydiscrete) {
 				y0 = gog_axis_map_to_view (y_map, i);
 				y1 = gog_axis_map_to_view (y_map, i + 1);
 			} else {
-				y0 = gog_axis_map_to_view (y_map, go_data_vector_get_value (y_vec, i - 1));
-				y1 = gog_axis_map_to_view (y_map, go_data_vector_get_value (y_vec, i));
+				y0 = gog_axis_map_to_view (y_map, go_data_get_vector_value (y_vec, i - 1));
+				y1 = gog_axis_map_to_view (y_map, go_data_get_vector_value (y_vec, i));
 			}
 			nans = 0;
 			nan = 4;
@@ -1041,4 +1041,4 @@ gog_contour_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogContourView, gog_contour_view,
 	gog_contour_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
